Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/gohugoio/hugoTestProjectJSModImports.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBjørn Erik Pedersen <bjorn.erik.pedersen@gmail.com>2020-11-04 20:25:03 +0300
committerBjørn Erik Pedersen <bjorn.erik.pedersen@gmail.com>2020-11-04 20:25:03 +0300
commitb70f2cc58a5e72dbc842f15b54cf17b2118babee (patch)
tree0f192ada293c007c551180dc27e4fc28dcce2938
parent0db16a75eb530737b1f9fc71eca71dd889599dae (diff)
Add one more hellov0.5.0
-rw-r--r--assets/js/main.js5
-rw-r--r--go.mod2
-rw-r--r--go.sum1
-rw-r--r--layouts/index.html1
4 files changed, 6 insertions, 3 deletions
diff --git a/go.mod b/go.mod
index ee98c2b..6487d5a 100644
--- a/go.mod
+++ b/go.mod
@@ -6,7 +6,7 @@ require (
github.com/bep/hugo-jslibs/alpinejs v0.5.14 // indirect
github.com/date-fns/date-fns v2.16.1+incompatible // indirect
github.com/gohugoio/hugoTestModulesJS/mod1 v0.2.0 // indirect
- github.com/gohugoio/hugoTestModulesJS/mod2 v0.2.0 // indirect
+ github.com/gohugoio/hugoTestModulesJS/mod2 v0.3.0 // indirect
)
diff --git a/go.sum b/go.sum
index 024b9ba..a748761 100644
--- a/go.sum
+++ b/go.sum
@@ -18,3 +18,4 @@ github.com/gohugoio/hugoTestModulesJS/mod2 v0.0.0-20201011192008-decf54abafdd h1
github.com/gohugoio/hugoTestModulesJS/mod2 v0.0.0-20201011192008-decf54abafdd/go.mod h1:uynOkor8I03PIUuDZN4NYQ+Bmkye7vNLV5tRUBC2+10=
github.com/gohugoio/hugoTestModulesJS/mod2 v0.1.0/go.mod h1:uynOkor8I03PIUuDZN4NYQ+Bmkye7vNLV5tRUBC2+10=
github.com/gohugoio/hugoTestModulesJS/mod2 v0.2.0/go.mod h1:uynOkor8I03PIUuDZN4NYQ+Bmkye7vNLV5tRUBC2+10=
+github.com/gohugoio/hugoTestModulesJS/mod2 v0.3.0/go.mod h1:uynOkor8I03PIUuDZN4NYQ+Bmkye7vNLV5tRUBC2+10=
diff --git a/layouts/index.html b/layouts/index.html
index e081f53..19cd5a9 100644
--- a/layouts/index.html
+++ b/layouts/index.html
@@ -16,6 +16,7 @@
<li x-text="hello2()"></li>
<li x-text="hello3()"></li>
<li x-text="hello4()"></li>
+ <li x-text="hello6()"></li>
<li x-text="data.Hugo"></li>
<li x-text="params.myparam"></li>
</ul>
diff --git a/assets/js/main.js b/assets/js/main.js
index f65fb47..7ba537e 100644
--- a/assets/js/main.js
+++ b/assets/js/main.js
@@ -2,10 +2,10 @@
import { hello1, hello2 } from 'core/util';
// From mod2
import * as data from 'core/util/data.json';
// hello3 lives in mod2 which also have a index.js in util.
// But doing import from 'core/util' you will get the index.js file from mod1
// (higher up in the import list), so we need to be explicit:
-import { hello3 } from 'core/util/hello3';
+import { hello3, hello6 } from 'core/util/hello3';
// From main
import { hello4 } from './lib';
@@ -16,5 +16,6 @@ window.hello1 = hello1;
window.hello2 = hello2;
window.hello3 = hello3;
window.hello4 = hello4;
+window.hello6 = hello6;
window.data = data;
window.params = params;
@@ -2,10 +2,10 @@
// From mod2
import * as data from 'core/util/data.json';
-// hello3 lives in mod2 which also have a index.js in util.
+// hello3, hello6 lives in mod2 which also have a index.js in util.
// But doing import from 'core/util' you will get the index.js file from mod1
// (higher up in the import list), so we need to be explicit: